Reader

Struct Reader 

pub struct Reader<'slice> { /* private fields */ }

Implementations

Source

impl<'slice> Reader<'slice>

pub fn new(data: &[u8]) -> Reader<'_>

Construct a new Reader wrapper over data.

pub fn read_obj<T: FromBytes>(&mut self) -> Result<T>

Reads and consumes an object from the buffer.

pub fn available_bytes(&self) -> usize

pub fn peek_obj<T: FromBytes>(&self) -> Result<T>

Reads an object from the buffer without consuming it.

pub fn read_exact(&mut self, buf: &mut [u8]) -> Result<()>

pub fn consume(&mut self, amt: usize)

Consumes amt bytes from the underlying buffer. If amt is larger than the remaining data left in this Reader, then all remaining data will be consumed.